#[non_exhaustive]pub enum State {
Unspecified,
PendingCreate,
Ready,
Creating,
Deleting,
Failed,
RolledBack,
UnknownValue(UnknownValue),
}Expand description
State contains all valid instance states for the BatchCreateInstances operation. This is mainly used for status reporting through the LRO metadata.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The state of the instance is unknown.
PendingCreate
Instance is pending creation and has not yet been picked up for processing in the backend.
Ready
The instance is active and running.
Creating
The instance is being created.
Deleting
The instance is being deleted.
Failed
The creation of the instance failed or a fatal error occurred during an operation on the instance or a batch of instances.
RolledBack
The instance was created successfully, but was rolled back and deleted due to some other failure during BatchCreateInstances operation.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations