#[non_exhaustive]pub enum ClusterView {
Unspecified,
Basic,
ContinuousBackup,
UnknownValue(UnknownValue),
}Expand description
View on Cluster. Pass this enum to rpcs that returns a cluster message to control which subsets of fields to get.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
CLUSTER_VIEW_UNSPECIFIED Not specified, equivalent to BASIC.
Basic
BASIC server responses include all the relevant cluster details, excluding Cluster.ContinuousBackupInfo.EarliestRestorableTime and other view-specific fields. The default value.
ContinuousBackup
CONTINUOUS_BACKUP response returns all the fields from BASIC plus the earliest restorable time if continuous backups are enabled. May increase latency.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ClusterView::value or ClusterView::name.
Implementations