#[non_exhaustive]pub enum DatabaseVersion {
Unspecified,
Postgres13,
Postgres14,
Postgres15,
Postgres16,
Postgres17,
UnknownValue(UnknownValue),
}Expand description
The supported database engine versions.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
This is an unknown database version.
Postgres13
DEPRECATED - The database version is Postgres 13.
Postgres14
The database version is Postgres 14.
Postgres15
The database version is Postgres 15.
Postgres16
The database version is Postgres 16.
Postgres17
The database version is Postgres 17.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using DatabaseVersion::value or DatabaseVersion::name.
Implementations