InstanceView

Enum InstanceView 

#[non_exhaustive]
pub enum InstanceView { Unspecified, Basic, Full, UnknownValue(UnknownValue), }
View on Instance. Pass this enum to rpcs that returns an Instance message to control which subsets of fields to get.

Working with unknown values

This enum is defined as #[non_exhaustive] because Google Cloud may add additional enum variants at any time. Adding new variants is not considered a breaking change. Applications should write their code in anticipation of:

  • New values appearing in future releases of the client library, and
  • New values received dynamically, without application changes.

Please consult the Working with enums section in the user guide for some guidelines.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unspecified

INSTANCE_VIEW_UNSPECIFIED Not specified, equivalent to BASIC.



Basic

BASIC server responses for a primary or read instance include all the relevant instance details, excluding the details of each node in the instance. The default value.



Full

FULL response is equivalent to BASIC for primary instance (for now). For read pool instance, this includes details of each node in the pool.



UnknownValue(UnknownValue)

If set, the enum was initialized with an unknown value.

Applications can examine the value using InstanceView::value or InstanceView::name.

Implementations

Source

impl InstanceView

pub fn value(&self) -> Option<i32>

Gets the enum value.

Returns None if the enum contains an unknown value deserialized from the string representation of enums.

pub fn name(&self) -> Option<&str>

Gets the enum value as a string.

Returns None if the enum contains an unknown value deserialized from the integer representation of enums.