#[non_exhaustive]pub enum SubscriptionType {
Unspecified,
Standard,
Trial,
UnknownValue(UnknownValue),
}Expand description
Subscription_type added to distinguish between Standard and Trial subscriptions. By default, a subscription type is considered STANDARD unless explicitly specified.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
This is an unknown subscription type. By default, the subscription type is STANDARD.
Standard
Standard subscription.
Trial
Trial subscription.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using SubscriptionType::value or SubscriptionType::name.
Implementations