#[non_exhaustive]pub enum Status {
Unspecified,
Ok,
Partial,
Error,
UnknownValue(UnknownValue),
}Expand description
Status contains all valid Status a SQL execution can end up in.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The status is unknown.
Ok
No error during SQL execution i.e. All SQL statements ran to completion. The “message” will be empty.
Partial
Same as OK, except indicates that only partial results were returned. The “message” field will contain details on why results were truncated.
Error
Error during SQL execution. Atleast 1 SQL statement execution resulted in a error. Side effects of other statements are rolled back. The “message” field will contain human readable error given by Postgres of the first bad SQL statement. SQL execution errors don’t constitute API errors as defined in https://google.aip.dev/193 but will be returned as part of this message.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Status::value or Status::name.
Implementations