#[non_exhaustive]pub enum State {
Unspecified,
Ready,
Stopped,
Creating,
Deleting,
Maintenance,
Failed,
Bootstrapping,
Promoting,
UnknownValue(UnknownValue),
}Expand description
Instance State
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The state of the instance is unknown.
Ready
The instance is active and running.
Stopped
The instance is stopped. Instance name and IP resources are preserved.
Creating
The instance is being created.
Deleting
The instance is being deleted.
Maintenance
The instance is down for maintenance.
Failed
The creation of the instance failed or a fatal error occurred during an operation on the instance. Note: Instances in this state would tried to be auto-repaired. And Customers should be able to restart, update or delete these instances.
Bootstrapping
Index 7 is used in the producer apis for ROLLED_BACK state. Keeping that index unused in case that state also needs to exposed via consumer apis in future. The instance has been configured to sync data from some other source.
Promoting
The instance is being promoted.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations