InstanceNetworkConfig

Struct InstanceNetworkConfig 

#[non_exhaustive]
pub struct InstanceNetworkConfig { pub authorized_external_networks: Vec<AuthorizedNetwork>, pub enable_public_ip: bool, pub enable_outbound_public_ip: bool, pub network: String, pub allocated_ip_range_override: String, /* private fields */ }
Metadata related to instance-level network configuration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
authorized_external_networks: Vec<AuthorizedNetwork>

Optional. A list of external network authorized to access this instance.

enable_public_ip: bool

Optional. Enabling public ip for the instance.

enable_outbound_public_ip: bool

Optional. Enabling an outbound public IP address to support a database server sending requests out into the internet.

network: String

Output only. The resource link for the VPC network in which instance resources are created and from which they are accessible via Private IP. This will be the same value as the parent cluster’s network. It is specified in the form: // projects/{project_number}/global/networks/{network_id}.

allocated_ip_range_override: String

Optional. Name of the allocated IP range for the private IP AlloyDB instance, for example: “google-managed-services-default”. If set, the instance IPs will be created from this allocated range and will override the IP range used by the parent cluster. The range name must comply with RFC 1035. Specifically, the name must be 1-63 characters long and match the regular expression a-z?.

Implementations

Source

impl InstanceNetworkConfig

pub fn new() -> Self

pub fn set_authorized_external_networks<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<AuthorizedNetwork>,

Sets the value of authorized_external_networks.

Example
use google_cloud_alloydb_v1::model::instance::instance_network_config::AuthorizedNetwork;
let x = InstanceNetworkConfig::new()
    .set_authorized_external_networks([
        AuthorizedNetwork::default()/* use setters */,
        AuthorizedNetwork::default()/* use (different) setters */,
    ]);
pub fn set_enable_public_ip<T: Into<bool>>(self, v: T) -> Self

Sets the value of enable_public_ip.

Example
let x = InstanceNetworkConfig::new().set_enable_public_ip(true);
pub fn set_enable_outbound_public_ip<T: Into<bool>>(self, v: T) -> Self

Sets the value of enable_outbound_public_ip.

Example
let x = InstanceNetworkConfig::new().set_enable_outbound_public_ip(true);
pub fn set_network<T: Into<String>>(self, v: T) -> Self

Sets the value of network.

Example
let x = InstanceNetworkConfig::new().set_network("example");
pub fn set_allocated_ip_range_override<T: Into<String>>(self, v: T) -> Self

Sets the value of allocated_ip_range_override.

Example
let x = InstanceNetworkConfig::new().set_allocated_ip_range_override("example");