ObservabilityInstanceConfig

Struct ObservabilityInstanceConfig 

#[non_exhaustive]
pub struct ObservabilityInstanceConfig { pub enabled: Option<bool>, pub preserve_comments: Option<bool>, pub track_wait_events: Option<bool>, pub track_wait_event_types: Option<bool>, pub max_query_string_length: Option<i32>, pub record_application_tags: Option<bool>, pub query_plans_per_minute: Option<i32>, pub track_active_queries: Option<bool>, /* private fields */ }
Observability Instance specific configuration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
enabled: Option<bool>

Observability feature status for an instance. This flag is turned “off” by default.

preserve_comments: Option<bool>

Preserve comments in query string for an instance. This flag is turned “off” by default.

track_wait_events: Option<bool>

Track wait events during query execution for an instance. This flag is turned “on” by default but tracking is enabled only after observability enabled flag is also turned on.

track_wait_event_types: Option<bool>

Output only. Track wait event types during query execution for an instance. This flag is turned “on” by default but tracking is enabled only after observability enabled flag is also turned on. This is read-only flag and only modifiable by internal API.

max_query_string_length: Option<i32>

Query string length. The default value is 10k.

record_application_tags: Option<bool>

Record application tags for an instance. This flag is turned “off” by default.

query_plans_per_minute: Option<i32>

Number of query execution plans captured by Insights per minute for all queries combined. The default value is 200. Any integer between 0 to 200 is considered valid.

track_active_queries: Option<bool>

Track actively running queries on the instance. If not set, this flag is “off” by default.

Implementations

Source

impl ObservabilityInstanceConfig

pub fn new() -> Self

pub fn set_enabled<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of enabled.

Example
let x = ObservabilityInstanceConfig::new().set_enabled(true);
pub fn set_or_clear_enabled<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of enabled.

Example
let x = ObservabilityInstanceConfig::new().set_or_clear_enabled(Some(false));
let x = ObservabilityInstanceConfig::new().set_or_clear_enabled(None::<bool>);
pub fn set_preserve_comments<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of preserve_comments.

Example
let x = ObservabilityInstanceConfig::new().set_preserve_comments(true);
pub fn set_or_clear_preserve_comments<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of preserve_comments.

Example
let x = ObservabilityInstanceConfig::new().set_or_clear_preserve_comments(Some(false));
let x = ObservabilityInstanceConfig::new().set_or_clear_preserve_comments(None::<bool>);
pub fn set_track_wait_events<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of track_wait_events.

Example
let x = ObservabilityInstanceConfig::new().set_track_wait_events(true);
pub fn set_or_clear_track_wait_events<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of track_wait_events.

Example
let x = ObservabilityInstanceConfig::new().set_or_clear_track_wait_events(Some(false));
let x = ObservabilityInstanceConfig::new().set_or_clear_track_wait_events(None::<bool>);
pub fn set_track_wait_event_types<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of track_wait_event_types.

Example
let x = ObservabilityInstanceConfig::new().set_track_wait_event_types(true);
pub fn set_or_clear_track_wait_event_types<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of track_wait_event_types.

Example
let x = ObservabilityInstanceConfig::new().set_or_clear_track_wait_event_types(Some(false));
let x = ObservabilityInstanceConfig::new().set_or_clear_track_wait_event_types(None::<bool>);
pub fn set_max_query_string_length<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of max_query_string_length.

Example
let x = ObservabilityInstanceConfig::new().set_max_query_string_length(42);
pub fn set_or_clear_max_query_string_length<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of max_query_string_length.

Example
let x = ObservabilityInstanceConfig::new().set_or_clear_max_query_string_length(Some(42));
let x = ObservabilityInstanceConfig::new().set_or_clear_max_query_string_length(None::<i32>);
pub fn set_record_application_tags<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of record_application_tags.

Example
let x = ObservabilityInstanceConfig::new().set_record_application_tags(true);
pub fn set_or_clear_record_application_tags<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of record_application_tags.

Example
let x = ObservabilityInstanceConfig::new().set_or_clear_record_application_tags(Some(false));
let x = ObservabilityInstanceConfig::new().set_or_clear_record_application_tags(None::<bool>);
pub fn set_query_plans_per_minute<T>(self, v: T) -> Self
where T: Into<i32>,

Sets the value of query_plans_per_minute.

Example
let x = ObservabilityInstanceConfig::new().set_query_plans_per_minute(42);
pub fn set_or_clear_query_plans_per_minute<T>(self, v: Option<T>) -> Self
where T: Into<i32>,

Sets or clears the value of query_plans_per_minute.

Example
let x = ObservabilityInstanceConfig::new().set_or_clear_query_plans_per_minute(Some(42));
let x = ObservabilityInstanceConfig::new().set_or_clear_query_plans_per_minute(None::<i32>);
pub fn set_track_active_queries<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of track_active_queries.

Example
let x = ObservabilityInstanceConfig::new().set_track_active_queries(true);
pub fn set_or_clear_track_active_queries<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of track_active_queries.

Example
let x = ObservabilityInstanceConfig::new().set_or_clear_track_active_queries(Some(false));
let x = ObservabilityInstanceConfig::new().set_or_clear_track_active_queries(None::<bool>);