#[non_exhaustive]pub struct PscInstanceConfig {
pub service_attachment_link: String,
pub allowed_consumer_projects: Vec<String>,
pub psc_dns_name: String,
pub psc_interface_configs: Vec<PscInterfaceConfig>,
pub psc_auto_connections: Vec<PscAutoConnectionConfig>,
/* private fields */
}Expand description
PscInstanceConfig contains PSC related configuration at an instance level.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.service_attachment_link: StringOutput only. The service attachment created when Private
Service Connect (PSC) is enabled for the instance.
The name of the resource will be in the format of
projects/<alloydb-tenant-project-number>/regions/<region-name>/serviceAttachments/<service-attachment-name>
allowed_consumer_projects: Vec<String>Optional. List of consumer projects that are allowed to create PSC endpoints to service-attachments to this instance.
psc_dns_name: StringOutput only. The DNS name of the instance for PSC connectivity. Name convention: <uid>.<uid>.<region>.alloydb-psc.goog
psc_interface_configs: Vec<PscInterfaceConfig>Optional. Configurations for setting up PSC interfaces attached to the instance which are used for outbound connectivity. Only primary instances can have PSC interface attached. Currently we only support 0 or 1 PSC interface.
psc_auto_connections: Vec<PscAutoConnectionConfig>Optional. Configurations for setting up PSC service automation.
Implementations
Sourceimpl PscInstanceConfig
impl PscInstanceConfig
pub fn new() -> Self
Sourcepub fn set_service_attachment_link<T: Into<String>>(self, v: T) -> Self
pub fn set_service_attachment_link<T: Into<String>>(self, v: T) -> Self
Sets the value of service_attachment_link.
Example
let x = PscInstanceConfig::new().set_service_attachment_link("example");Sourcepub fn set_allowed_consumer_projects<T, V>(self, v: T) -> Self
pub fn set_allowed_consumer_projects<T, V>(self, v: T) -> Self
Sets the value of allowed_consumer_projects.
Example
let x = PscInstanceConfig::new().set_allowed_consumer_projects(["a", "b", "c"]);Sourcepub fn set_psc_dns_name<T: Into<String>>(self, v: T) -> Self
pub fn set_psc_dns_name<T: Into<String>>(self, v: T) -> Self
Sets the value of psc_dns_name.
Example
let x = PscInstanceConfig::new().set_psc_dns_name("example");Sourcepub fn set_psc_interface_configs<T, V>(self, v: T) -> Self
pub fn set_psc_interface_configs<T, V>(self, v: T) -> Self
Sets the value of psc_interface_configs.
Example
use google_cloud_alloydb_v1::model::instance::PscInterfaceConfig;
let x = PscInstanceConfig::new()
.set_psc_interface_configs([
PscInterfaceConfig::default()/* use setters */,
PscInterfaceConfig::default()/* use (different) setters */,
]);Sourcepub fn set_psc_auto_connections<T, V>(self, v: T) -> Self
pub fn set_psc_auto_connections<T, V>(self, v: T) -> Self
Sets the value of psc_auto_connections.
Example
use google_cloud_alloydb_v1::model::instance::PscAutoConnectionConfig;
let x = PscInstanceConfig::new()
.set_psc_auto_connections([
PscAutoConnectionConfig::default()/* use setters */,
PscAutoConnectionConfig::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for PscInstanceConfig
impl Clone for PscInstanceConfig
Sourcefn clone(&self) -> PscInstanceConfig
fn clone(&self) -> PscInstanceConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more