#[non_exhaustive]pub struct PscInterfaceConfig {
pub network_attachment_resource: String,
/* private fields */
}Expand description
Configuration for setting up a PSC interface to enable outbound connectivity.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.network_attachment_resource: StringThe network attachment resource created in the consumer network to which the PSC interface will be linked. This is of the format: “projects/${CONSUMER_PROJECT}/regions/${REGION}/networkAttachments/${NETWORK_ATTACHMENT_NAME}”. The network attachment must be in the same region as the instance.
Implementations
Sourceimpl PscInterfaceConfig
impl PscInterfaceConfig
pub fn new() -> Self
Sourcepub fn set_network_attachment_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_network_attachment_resource<T: Into<String>>(self, v: T) -> Self
Sets the value of network_attachment_resource.
Example
ⓘ
let x = PscInterfaceConfig::new().set_network_attachment_resource("example");Trait Implementations
Sourceimpl Clone for PscInterfaceConfig
impl Clone for PscInterfaceConfig
Sourcefn clone(&self) -> PscInterfaceConfig
fn clone(&self) -> PscInterfaceConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PscInterfaceConfig
impl Debug for PscInterfaceConfig
Sourceimpl Default for PscInterfaceConfig
impl Default for PscInterfaceConfig
Sourcefn default() -> PscInterfaceConfig
fn default() -> PscInterfaceConfig
Returns the “default value” for a type. Read more
Sourceimpl Message for PscInterfaceConfig
impl Message for PscInterfaceConfig
Sourceimpl PartialEq for PscInterfaceConfig
impl PartialEq for PscInterfaceConfig
impl StructuralPartialEq for PscInterfaceConfig