#[non_exhaustive]pub struct BackupSource {
pub backup_uid: String,
pub backup_name: String,
/* private fields */
}Expand description
Message describing a BackupSource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.backup_uid: StringOutput only. The system-generated UID of the backup which was used to create this resource. The UID is generated when the backup is created, and it is retained until the backup is deleted.
backup_name: StringRequired. The name of the backup resource with the format:
- projects/{project}/locations/{region}/backups/{backup_id}
Implementations
Sourceimpl BackupSource
impl BackupSource
pub fn new() -> Self
Sourcepub fn set_backup_uid<T: Into<String>>(self, v: T) -> Self
pub fn set_backup_uid<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_backup_name<T: Into<String>>(self, v: T) -> Self
pub fn set_backup_name<T: Into<String>>(self, v: T) -> Self