BatchCreateInstancesMetadata

Struct BatchCreateInstancesMetadata 

#[non_exhaustive]
pub struct BatchCreateInstancesMetadata { pub instance_targets: Vec<String>, pub instance_statuses: HashMap<String, BatchCreateInstanceStatus>, /* private fields */ }
Message for metadata that is specific to BatchCreateInstances API. NEXT_ID: 3

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
instance_targets: Vec<String>

The instances being created in the API call. Each string in this list is the server defined resource path for target instances in the request and for the format of each string, see the comment on the Instance.name field.

instance_statuses: HashMap<String, BatchCreateInstanceStatus>

A map representing state of the instances involved in the BatchCreateInstances operation during the operation execution. The instance state will be in STATE_UNSPECIFIED state if the instance has not yet been picked up for processing. The key of the map is the name of the instance resource. For the format, see the comment on the Instance.name field.

Implementations

Source

impl BatchCreateInstancesMetadata

pub fn new() -> Self

pub fn set_instance_targets<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of instance_targets.

Example
let x = BatchCreateInstancesMetadata::new().set_instance_targets(["a", "b", "c"]);
pub fn set_instance_statuses<T, K, V>(self, v: T) -> Self

Sets the value of instance_statuses.

Example
use google_cloud_alloydb_v1::model::BatchCreateInstanceStatus;
let x = BatchCreateInstancesMetadata::new().set_instance_statuses([
    ("key0", BatchCreateInstanceStatus::default()/* use setters */),
    ("key1", BatchCreateInstanceStatus::default()/* use (different) setters */),
]);