#[non_exhaustive]pub struct BatchCreateInstancesRequest {
pub parent: String,
pub requests: Option<CreateInstanceRequests>,
pub request_id: String,
/* private fields */
}Expand description
Message for creating a batch of instances under the specified cluster.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the parent resource.
requests: Option<CreateInstanceRequests>Required. Resources being created.
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Implementations
Sourceimpl BatchCreateInstancesRequest
impl BatchCreateInstancesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_requests<T>(self, v: T) -> Selfwhere
T: Into<CreateInstanceRequests>,
pub fn set_requests<T>(self, v: T) -> Selfwhere
T: Into<CreateInstanceRequests>,
Sourcepub fn set_or_clear_requests<T>(self, v: Option<T>) -> Selfwhere
T: Into<CreateInstanceRequests>,
pub fn set_or_clear_requests<T>(self, v: Option<T>) -> Selfwhere
T: Into<CreateInstanceRequests>,
Sets or clears the value of requests.
Example
use google_cloud_alloydb_v1::model::CreateInstanceRequests;
let x = BatchCreateInstancesRequest::new().set_or_clear_requests(Some(CreateInstanceRequests::default()/* use setters */));
let x = BatchCreateInstancesRequest::new().set_or_clear_requests(None::<CreateInstanceRequests>);Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = BatchCreateInstancesRequest::new().set_request_id("example");Trait Implementations
Sourceimpl Clone for BatchCreateInstancesRequest
impl Clone for BatchCreateInstancesRequest
Sourcefn clone(&self) -> BatchCreateInstancesRequest
fn clone(&self) -> BatchCreateInstancesRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more