ContinuousBackupConfig

Struct ContinuousBackupConfig 

#[non_exhaustive]
pub struct ContinuousBackupConfig { pub enabled: Option<bool>, pub recovery_window_days: i32, pub encryption_config: Option<EncryptionConfig>, /* private fields */ }
ContinuousBackupConfig describes the continuous backups recovery configurations of a cluster.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
enabled: Option<bool>

Whether ContinuousBackup is enabled.

recovery_window_days: i32

The number of days that are eligible to restore from using PITR. To support the entire recovery window, backups and logs are retained for one day more than the recovery window. If not set, defaults to 14 days.

encryption_config: Option<EncryptionConfig>

The encryption config can be specified to encrypt the backups with a customer-managed encryption key (CMEK). When this field is not specified, the backup will use the cluster’s encryption config.

Implementations

Source

impl ContinuousBackupConfig

pub fn new() -> Self

pub fn set_enabled<T>(self, v: T) -> Self
where T: Into<bool>,

Sets the value of enabled.

Example
let x = ContinuousBackupConfig::new().set_enabled(true);
pub fn set_or_clear_enabled<T>(self, v: Option<T>) -> Self
where T: Into<bool>,

Sets or clears the value of enabled.

Example
let x = ContinuousBackupConfig::new().set_or_clear_enabled(Some(false));
let x = ContinuousBackupConfig::new().set_or_clear_enabled(None::<bool>);
pub fn set_recovery_window_days<T: Into<i32>>(self, v: T) -> Self

Sets the value of recovery_window_days.

Example
let x = ContinuousBackupConfig::new().set_recovery_window_days(42);
pub fn set_encryption_config<T>(self, v: T) -> Self

Sets the value of encryption_config.

Example
use google_cloud_alloydb_v1::model::EncryptionConfig;
let x = ContinuousBackupConfig::new().set_encryption_config(EncryptionConfig::default()/* use setters */);
pub fn set_or_clear_encryption_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of encryption_config.

Example
use google_cloud_alloydb_v1::model::EncryptionConfig;
let x = ContinuousBackupConfig::new().set_or_clear_encryption_config(Some(EncryptionConfig::default()/* use setters */));
let x = ContinuousBackupConfig::new().set_or_clear_encryption_config(None::<EncryptionConfig>);