ContinuousBackupSource

Struct ContinuousBackupSource 

#[non_exhaustive]
pub struct ContinuousBackupSource { pub cluster: String, pub point_in_time: Option<Timestamp>, /* private fields */ }
Message describing a ContinuousBackupSource.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
cluster: String

Required. The source cluster from which to restore. This cluster must have continuous backup enabled for this operation to succeed. For the required format, see the comment on the Cluster.name field.

point_in_time: Option<Timestamp>

Required. The point in time to restore to.

Implementations

Source

impl ContinuousBackupSource

pub fn new() -> Self

pub fn set_cluster<T: Into<String>>(self, v: T) -> Self

Sets the value of cluster.

Example
let x = ContinuousBackupSource::new().set_cluster("example");
pub fn set_point_in_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of point_in_time.

Example
use wkt::Timestamp;
let x = ContinuousBackupSource::new().set_point_in_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_point_in_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of point_in_time.

Example
use wkt::Timestamp;
let x = ContinuousBackupSource::new().set_or_clear_point_in_time(Some(Timestamp::default()/* use setters */));
let x = ContinuousBackupSource::new().set_or_clear_point_in_time(None::<Timestamp>);