#[non_exhaustive]pub struct CreateClusterRequest {
pub parent: String,
pub cluster_id: String,
pub cluster: Option<Cluster>,
pub request_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
Message for creating a Cluster
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The location of the new cluster. For the required format, see the comment on the Cluster.name field.
cluster_id: StringRequired. ID of the requesting object.
cluster: Option<Cluster>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
validate_only: boolOptional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request.
Implementations
Sourceimpl CreateClusterRequest
impl CreateClusterRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_cluster_id<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster_id<T: Into<String>>(self, v: T) -> Self
Sets the value of cluster_id.
Example
let x = CreateClusterRequest::new().set_cluster_id("example");Sourcepub fn set_cluster<T>(self, v: T) -> Self
pub fn set_cluster<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_cluster<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_cluster<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateClusterRequest::new().set_request_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateClusterRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateClusterRequest
impl Clone for CreateClusterRequest
Sourcefn clone(&self) -> CreateClusterRequest
fn clone(&self) -> CreateClusterRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more