#[non_exhaustive]pub struct CreateSecondaryInstanceRequest {
pub parent: String,
pub instance_id: String,
pub instance: Option<Instance>,
pub request_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
Message for creating a Secondary Instance
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the parent resource. For the required format, see the comment on the Instance.name field.
instance_id: StringRequired. ID of the requesting object.
instance: Option<Instance>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
validate_only: boolOptional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request.
Implementations
Sourceimpl CreateSecondaryInstanceRequest
impl CreateSecondaryInstanceRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_instance_id<T: Into<String>>(self, v: T) -> Self
pub fn set_instance_id<T: Into<String>>(self, v: T) -> Self
Sets the value of instance_id.
Example
let x = CreateSecondaryInstanceRequest::new().set_instance_id("example");Sourcepub fn set_instance<T>(self, v: T) -> Self
pub fn set_instance<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_instance<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_instance<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sets the value of request_id.
Example
let x = CreateSecondaryInstanceRequest::new().set_request_id("example");Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateSecondaryInstanceRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateSecondaryInstanceRequest
impl Clone for CreateSecondaryInstanceRequest
Sourcefn clone(&self) -> CreateSecondaryInstanceRequest
fn clone(&self) -> CreateSecondaryInstanceRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Default for CreateSecondaryInstanceRequest
impl Default for CreateSecondaryInstanceRequest
Sourcefn default() -> CreateSecondaryInstanceRequest
fn default() -> CreateSecondaryInstanceRequest
Sourceimpl PartialEq for CreateSecondaryInstanceRequest
impl PartialEq for CreateSecondaryInstanceRequest
Sourcefn eq(&self, other: &CreateSecondaryInstanceRequest) -> bool
fn eq(&self, other: &CreateSecondaryInstanceRequest) -> bool
self and other values to be equal, and is used by ==.