#[non_exhaustive]pub struct CreateUserRequest {
pub parent: String,
pub user_id: String,
pub user: Option<User>,
pub request_id: String,
pub validate_only: bool,
/* private fields */
}Expand description
Message for creating a User
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Value for parent.
user_id: StringRequired. ID of the requesting object.
user: Option<User>Required. The resource being created
request_id: StringOptional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
validate_only: boolOptional. If set, the backend validates the request, but doesn’t actually execute it.
Implementations
Sourceimpl CreateUserRequest
impl CreateUserRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_user_id<T: Into<String>>(self, v: T) -> Self
pub fn set_user_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_or_clear_user<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_user<T>(self, v: Option<T>) -> Self
Sourcepub fn set_request_id<T: Into<String>>(self, v: T) -> Self
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
let x = CreateUserRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for CreateUserRequest
impl Clone for CreateUserRequest
Sourcefn clone(&self) -> CreateUserRequest
fn clone(&self) -> CreateUserRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more