InjectFaultRequest

Struct InjectFaultRequest 

#[non_exhaustive]
pub struct InjectFaultRequest { pub fault_type: FaultType, pub name: String, pub request_id: String, pub validate_only: bool, /* private fields */ }
Message for triggering fault injection on an instance

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
fault_type: FaultType

Required. The type of fault to be injected in an instance.

name: String

Required. The name of the resource. For the required format, see the comment on the Instance.name field.

request_id: String

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

validate_only: bool

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request.

Implementations

Source

impl InjectFaultRequest

pub fn new() -> Self

pub fn set_fault_type<T: Into<FaultType>>(self, v: T) -> Self

Sets the value of fault_type.

Example
use google_cloud_alloydb_v1::model::inject_fault_request::FaultType;
let x0 = InjectFaultRequest::new().set_fault_type(FaultType::StopVm);
pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = InjectFaultRequest::new().set_name("example");
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self

Sets the value of request_id.

Example
let x = InjectFaultRequest::new().set_request_id("example");
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self

Sets the value of validate_only.

Example
let x = InjectFaultRequest::new().set_validate_only(true);