Instance

Struct Instance 

#[non_exhaustive]
pub struct Instance {
Show 30 fields pub name: String, pub display_name: String, pub uid: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub delete_time: Option<Timestamp>, pub labels: HashMap<String, String>, pub state: State, pub instance_type: InstanceType, pub machine_config: Option<MachineConfig>, pub availability_type: AvailabilityType, pub gce_zone: String, pub database_flags: HashMap<String, String>, pub writable_node: Option<Node>, pub nodes: Vec<Node>, pub query_insights_config: Option<QueryInsightsInstanceConfig>, pub observability_config: Option<ObservabilityInstanceConfig>, pub read_pool_config: Option<ReadPoolConfig>, pub ip_address: String, pub public_ip_address: String, pub reconciling: bool, pub etag: String, pub annotations: HashMap<String, String>, pub client_connection_config: Option<ClientConnectionConfig>, pub satisfies_pzs: bool, pub psc_instance_config: Option<PscInstanceConfig>, pub network_config: Option<InstanceNetworkConfig>, pub outbound_public_ip_addresses: Vec<String>, pub activation_policy: ActivationPolicy, pub connection_pool_config: Option<ConnectionPoolConfig>, /* private fields */
}
An Instance is a computing unit that an end customer can connect to. It’s the main unit of computing resources in AlloyDB.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. The name of the instance resource with the format:

  • projects/{project}/locations/{region}/clusters/{cluster_id}/instances/{instance_id} where the cluster and instance ID segments should satisfy the regex expression [a-z]([a-z0-9-]{0,61}[a-z0-9])?, e.g. 1-63 characters of lowercase letters, numbers, and dashes, starting with a letter, and ending with a letter or number. For more details see https://google.aip.dev/122. The prefix of the instance resource name is the name of the parent resource:
  • projects/{project}/locations/{region}/clusters/{cluster_id}
display_name: String

User-settable and human-readable display name for the Instance.

uid: String

Output only. The system-generated UID of the resource. The UID is assigned when the resource is created, and it is retained until it is deleted.

create_time: Option<Timestamp>

Output only. Create time stamp

update_time: Option<Timestamp>

Output only. Update time stamp

delete_time: Option<Timestamp>

Output only. Delete time stamp

labels: HashMap<String, String>

Labels as key value pairs

state: State

Output only. The current serving state of the instance.

instance_type: InstanceType

Required. The type of the instance. Specified at creation time.

machine_config: Option<MachineConfig>

Configurations for the machines that host the underlying database engine.

availability_type: AvailabilityType

Availability type of an Instance. If empty, defaults to REGIONAL for primary instances. For read pools, availability_type is always UNSPECIFIED. Instances in the read pools are evenly distributed across available zones within the region (i.e. read pools with more than one node will have a node in at least two zones).

gce_zone: String

The Compute Engine zone that the instance should serve from, per https://cloud.google.com/compute/docs/regions-zones This can ONLY be specified for ZONAL instances. If present for a REGIONAL instance, an error will be thrown. If this is absent for a ZONAL instance, instance is created in a random zone with available capacity.

database_flags: HashMap<String, String>

Database flags. Set at the instance level. They are copied from the primary instance on secondary instance creation. Flags that have restrictions default to the value at primary instance on read instances during creation. Read instances can set new flags or override existing flags that are relevant for reads, for example, for enabling columnar cache on a read instance. Flags set on read instance might or might not be present on the primary instance.

This is a list of “key”: “value” pairs. “key”: The name of the flag. These flags are passed at instance setup time, so include both server options and system variables for Postgres. Flags are specified with underscores, not hyphens. “value”: The value of the flag. Booleans are set to on for true and off for false. This field must be omitted if the flag doesn’t take a value.

writable_node: Option<Node>

Output only. This is set for the read-write VM of the PRIMARY instance only.

nodes: Vec<Node>

Output only. List of available read-only VMs in this instance, including the standby for a PRIMARY instance.

query_insights_config: Option<QueryInsightsInstanceConfig>

Configuration for query insights.

observability_config: Option<ObservabilityInstanceConfig>

Configuration for observability.

read_pool_config: Option<ReadPoolConfig>

Read pool instance configuration. This is required if the value of instanceType is READ_POOL.

ip_address: String

Output only. The IP address for the Instance. This is the connection endpoint for an end-user application.

public_ip_address: String

Output only. The public IP addresses for the Instance. This is available ONLY when enable_public_ip is set. This is the connection endpoint for an end-user application.

reconciling: bool

Output only. Reconciling (https://google.aip.dev/128#reconciliation). Set to true if the current state of Instance does not match the user’s intended state, and the service is actively updating the resource to reconcile them. This can happen due to user-triggered updates or system actions like failover or maintenance.

etag: String

For Resource freshness validation (https://google.aip.dev/154)

annotations: HashMap<String, String>

Annotations to allow client tools to store small amount of arbitrary data. This is distinct from labels. https://google.aip.dev/128

client_connection_config: Option<ClientConnectionConfig>

Optional. Client connection specific configurations

satisfies_pzs: bool

Output only. Reserved for future use.

psc_instance_config: Option<PscInstanceConfig>

Optional. The configuration for Private Service Connect (PSC) for the instance.

network_config: Option<InstanceNetworkConfig>

Optional. Instance-level network configuration.

outbound_public_ip_addresses: Vec<String>

Output only. All outbound public IP addresses configured for the instance.

activation_policy: ActivationPolicy

Optional. Specifies whether an instance needs to spin up. Once the instance is active, the activation policy can be updated to the NEVER to stop the instance. Likewise, the activation policy can be updated to ALWAYS to start the instance. There are restrictions around when an instance can/cannot be activated (for example, a read pool instance should be stopped before stopping primary etc.). Please refer to the API documentation for more details.

connection_pool_config: Option<ConnectionPoolConfig>

Optional. The configuration for Managed Connection Pool (MCP).

Implementations

Source

impl Instance

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Instance::new().set_name("example");
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self

Sets the value of display_name.

Example
let x = Instance::new().set_display_name("example");
pub fn set_uid<T: Into<String>>(self, v: T) -> Self

Sets the value of uid.

Example
let x = Instance::new().set_uid("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_delete_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of delete_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_delete_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_delete_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of delete_time.

Example
use wkt::Timestamp;
let x = Instance::new().set_or_clear_delete_time(Some(Timestamp::default()/* use setters */));
let x = Instance::new().set_or_clear_delete_time(None::<Timestamp>);
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Instance::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_alloydb_v1::model::instance::State;
let x0 = Instance::new().set_state(State::Ready);
let x1 = Instance::new().set_state(State::Stopped);
let x2 = Instance::new().set_state(State::Creating);
pub fn set_instance_type<T: Into<InstanceType>>(self, v: T) -> Self

Sets the value of instance_type.

Example
use google_cloud_alloydb_v1::model::instance::InstanceType;
let x0 = Instance::new().set_instance_type(InstanceType::Primary);
let x1 = Instance::new().set_instance_type(InstanceType::ReadPool);
let x2 = Instance::new().set_instance_type(InstanceType::Secondary);
pub fn set_machine_config<T>(self, v: T) -> Self
where T: Into<MachineConfig>,

Sets the value of machine_config.

Example
use google_cloud_alloydb_v1::model::instance::MachineConfig;
let x = Instance::new().set_machine_config(MachineConfig::default()/* use setters */);
pub fn set_or_clear_machine_config<T>(self, v: Option<T>) -> Self
where T: Into<MachineConfig>,

Sets or clears the value of machine_config.

Example
use google_cloud_alloydb_v1::model::instance::MachineConfig;
let x = Instance::new().set_or_clear_machine_config(Some(MachineConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_machine_config(None::<MachineConfig>);
pub fn set_availability_type<T: Into<AvailabilityType>>(self, v: T) -> Self

Sets the value of availability_type.

Example
use google_cloud_alloydb_v1::model::instance::AvailabilityType;
let x0 = Instance::new().set_availability_type(AvailabilityType::Zonal);
let x1 = Instance::new().set_availability_type(AvailabilityType::Regional);
pub fn set_gce_zone<T: Into<String>>(self, v: T) -> Self

Sets the value of gce_zone.

Example
let x = Instance::new().set_gce_zone("example");
pub fn set_database_flags<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of database_flags.

Example
let x = Instance::new().set_database_flags([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_writable_node<T>(self, v: T) -> Self
where T: Into<Node>,

Sets the value of writable_node.

Example
use google_cloud_alloydb_v1::model::instance::Node;
let x = Instance::new().set_writable_node(Node::default()/* use setters */);
pub fn set_or_clear_writable_node<T>(self, v: Option<T>) -> Self
where T: Into<Node>,

Sets or clears the value of writable_node.

Example
use google_cloud_alloydb_v1::model::instance::Node;
let x = Instance::new().set_or_clear_writable_node(Some(Node::default()/* use setters */));
let x = Instance::new().set_or_clear_writable_node(None::<Node>);
pub fn set_nodes<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Node>,

Sets the value of nodes.

Example
use google_cloud_alloydb_v1::model::instance::Node;
let x = Instance::new()
    .set_nodes([
        Node::default()/* use setters */,
        Node::default()/* use (different) setters */,
    ]);
pub fn set_query_insights_config<T>(self, v: T) -> Self

Sets the value of query_insights_config.

Example
use google_cloud_alloydb_v1::model::instance::QueryInsightsInstanceConfig;
let x = Instance::new().set_query_insights_config(QueryInsightsInstanceConfig::default()/* use setters */);
pub fn set_or_clear_query_insights_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of query_insights_config.

Example
use google_cloud_alloydb_v1::model::instance::QueryInsightsInstanceConfig;
let x = Instance::new().set_or_clear_query_insights_config(Some(QueryInsightsInstanceConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_query_insights_config(None::<QueryInsightsInstanceConfig>);
pub fn set_observability_config<T>(self, v: T) -> Self

Sets the value of observability_config.

Example
use google_cloud_alloydb_v1::model::instance::ObservabilityInstanceConfig;
let x = Instance::new().set_observability_config(ObservabilityInstanceConfig::default()/* use setters */);
pub fn set_or_clear_observability_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of observability_config.

Example
use google_cloud_alloydb_v1::model::instance::ObservabilityInstanceConfig;
let x = Instance::new().set_or_clear_observability_config(Some(ObservabilityInstanceConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_observability_config(None::<ObservabilityInstanceConfig>);
pub fn set_read_pool_config<T>(self, v: T) -> Self
where T: Into<ReadPoolConfig>,

Sets the value of read_pool_config.

Example
use google_cloud_alloydb_v1::model::instance::ReadPoolConfig;
let x = Instance::new().set_read_pool_config(ReadPoolConfig::default()/* use setters */);
pub fn set_or_clear_read_pool_config<T>(self, v: Option<T>) -> Self
where T: Into<ReadPoolConfig>,

Sets or clears the value of read_pool_config.

Example
use google_cloud_alloydb_v1::model::instance::ReadPoolConfig;
let x = Instance::new().set_or_clear_read_pool_config(Some(ReadPoolConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_read_pool_config(None::<ReadPoolConfig>);
pub fn set_ip_address<T: Into<String>>(self, v: T) -> Self

Sets the value of ip_address.

Example
let x = Instance::new().set_ip_address("example");
pub fn set_public_ip_address<T: Into<String>>(self, v: T) -> Self

Sets the value of public_ip_address.

Example
let x = Instance::new().set_public_ip_address("example");
pub fn set_reconciling<T: Into<bool>>(self, v: T) -> Self

Sets the value of reconciling.

Example
let x = Instance::new().set_reconciling(true);
pub fn set_etag<T: Into<String>>(self, v: T) -> Self

Sets the value of etag.

Example
let x = Instance::new().set_etag("example");
pub fn set_annotations<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of annotations.

Example
let x = Instance::new().set_annotations([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_client_connection_config<T>(self, v: T) -> Self

Sets the value of client_connection_config.

Example
use google_cloud_alloydb_v1::model::instance::ClientConnectionConfig;
let x = Instance::new().set_client_connection_config(ClientConnectionConfig::default()/* use setters */);
pub fn set_or_clear_client_connection_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of client_connection_config.

Example
use google_cloud_alloydb_v1::model::instance::ClientConnectionConfig;
let x = Instance::new().set_or_clear_client_connection_config(Some(ClientConnectionConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_client_connection_config(None::<ClientConnectionConfig>);
pub fn set_satisfies_pzs<T: Into<bool>>(self, v: T) -> Self

Sets the value of satisfies_pzs.

Example
let x = Instance::new().set_satisfies_pzs(true);
pub fn set_psc_instance_config<T>(self, v: T) -> Self

Sets the value of psc_instance_config.

Example
use google_cloud_alloydb_v1::model::instance::PscInstanceConfig;
let x = Instance::new().set_psc_instance_config(PscInstanceConfig::default()/* use setters */);
pub fn set_or_clear_psc_instance_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of psc_instance_config.

Example
use google_cloud_alloydb_v1::model::instance::PscInstanceConfig;
let x = Instance::new().set_or_clear_psc_instance_config(Some(PscInstanceConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_psc_instance_config(None::<PscInstanceConfig>);
pub fn set_network_config<T>(self, v: T) -> Self

Sets the value of network_config.

Example
use google_cloud_alloydb_v1::model::instance::InstanceNetworkConfig;
let x = Instance::new().set_network_config(InstanceNetworkConfig::default()/* use setters */);
pub fn set_or_clear_network_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of network_config.

Example
use google_cloud_alloydb_v1::model::instance::InstanceNetworkConfig;
let x = Instance::new().set_or_clear_network_config(Some(InstanceNetworkConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_network_config(None::<InstanceNetworkConfig>);
pub fn set_outbound_public_ip_addresses<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of outbound_public_ip_addresses.

Example
let x = Instance::new().set_outbound_public_ip_addresses(["a", "b", "c"]);
pub fn set_activation_policy<T: Into<ActivationPolicy>>(self, v: T) -> Self

Sets the value of activation_policy.

Example
use google_cloud_alloydb_v1::model::instance::ActivationPolicy;
let x0 = Instance::new().set_activation_policy(ActivationPolicy::Always);
let x1 = Instance::new().set_activation_policy(ActivationPolicy::Never);
pub fn set_connection_pool_config<T>(self, v: T) -> Self

Sets the value of connection_pool_config.

Example
use google_cloud_alloydb_v1::model::instance::ConnectionPoolConfig;
let x = Instance::new().set_connection_pool_config(ConnectionPoolConfig::default()/* use setters */);
pub fn set_or_clear_connection_pool_config<T>(self, v: Option<T>) -> Self

Sets or clears the value of connection_pool_config.

Example
use google_cloud_alloydb_v1::model::instance::ConnectionPoolConfig;
let x = Instance::new().set_or_clear_connection_pool_config(Some(ConnectionPoolConfig::default()/* use setters */));
let x = Instance::new().set_or_clear_connection_pool_config(None::<ConnectionPoolConfig>);