#[non_exhaustive]pub struct ListDatabasesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Message for ListDatabases request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Parent value for ListDatabasesRequest.
page_size: i32Optional. The maximum number of databases to return. The service may return fewer than this value. If unspecified, 2000 is the default page_size. The max value of page_size will be 4000, values above max will be coerced to max.
page_token: StringOptional. A page token, received from a previous ListDatabases call.
This should be provided to retrieve the subsequent page.
This field is currently not supported, its value will be ignored if passed.
filter: StringOptional. Filtering results. This field is currently not supported, its value will be ignored if passed.
Implementations
Sourceimpl ListDatabasesRequest
impl ListDatabasesRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListDatabasesRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListDatabasesRequest
impl Clone for ListDatabasesRequest
Sourcefn clone(&self) -> ListDatabasesRequest
fn clone(&self) -> ListDatabasesRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListDatabasesRequest
impl Debug for ListDatabasesRequest
Sourceimpl Default for ListDatabasesRequest
impl Default for ListDatabasesRequest
Sourcefn default() -> ListDatabasesRequest
fn default() -> ListDatabasesRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListDatabasesRequest
impl Message for ListDatabasesRequest
Sourceimpl PartialEq for ListDatabasesRequest
impl PartialEq for ListDatabasesRequest
impl StructuralPartialEq for ListDatabasesRequest