#[non_exhaustive]pub struct ListSupportedDatabaseFlagsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub scope: Scope,
/* private fields */
}Expand description
Message for listing the information about the supported Database flags.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the parent resource. The required format is:
- projects/{project}/locations/{location}
Regardless of the parent specified here, as long it is contains a valid project and location, the service will return a static list of supported flags resources. Note that we do not yet support region-specific flags.
page_size: i32Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
page_token: StringA token identifying a page of results the server should return.
scope: ScopeOptional. The scope for which supported flags are requested. If not specified, default is DATABASE.
Implementations
Sourceimpl ListSupportedDatabaseFlagsRequest
impl ListSupportedDatabaseFlagsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListSupportedDatabaseFlagsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListSupportedDatabaseFlagsRequest
impl Clone for ListSupportedDatabaseFlagsRequest
Sourcefn clone(&self) -> ListSupportedDatabaseFlagsRequest
fn clone(&self) -> ListSupportedDatabaseFlagsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListSupportedDatabaseFlagsRequest
impl Default for ListSupportedDatabaseFlagsRequest
Sourcefn default() -> ListSupportedDatabaseFlagsRequest
fn default() -> ListSupportedDatabaseFlagsRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListSupportedDatabaseFlagsRequest
impl PartialEq for ListSupportedDatabaseFlagsRequest
Sourcefn eq(&self, other: &ListSupportedDatabaseFlagsRequest) -> bool
fn eq(&self, other: &ListSupportedDatabaseFlagsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListSupportedDatabaseFlagsRequest