#[non_exhaustive]pub struct ListSupportedDatabaseFlagsResponse {
pub supported_database_flags: Vec<SupportedDatabaseFlag>,
pub next_page_token: String,
/* private fields */
}Expand description
Message for response to listing SupportedDatabaseFlags.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.supported_database_flags: Vec<SupportedDatabaseFlag>The list of SupportedDatabaseFlags.
next_page_token: StringA token identifying a page of results the server should return.
Implementations
Sourceimpl ListSupportedDatabaseFlagsResponse
impl ListSupportedDatabaseFlagsResponse
pub fn new() -> Self
Sourcepub fn set_supported_database_flags<T, V>(self, v: T) -> Self
pub fn set_supported_database_flags<T, V>(self, v: T) -> Self
Sets the value of supported_database_flags.
Example
ⓘ
use google_cloud_alloydb_v1::model::SupportedDatabaseFlag;
let x = ListSupportedDatabaseFlagsResponse::new()
.set_supported_database_flags([
SupportedDatabaseFlag::default()/* use setters */,
SupportedDatabaseFlag::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListSupportedDatabaseFlagsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListSupportedDatabaseFlagsResponse
impl Clone for ListSupportedDatabaseFlagsResponse
Sourcefn clone(&self) -> ListSupportedDatabaseFlagsResponse
fn clone(&self) -> ListSupportedDatabaseFlagsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ListSupportedDatabaseFlagsResponse
impl Default for ListSupportedDatabaseFlagsResponse
Sourcefn default() -> ListSupportedDatabaseFlagsResponse
fn default() -> ListSupportedDatabaseFlagsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListSupportedDatabaseFlagsResponse
impl PartialEq for ListSupportedDatabaseFlagsResponse
Sourcefn eq(&self, other: &ListSupportedDatabaseFlagsResponse) -> bool
fn eq(&self, other: &ListSupportedDatabaseFlagsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListSupportedDatabaseFlagsResponse