UpdateInstanceRequest

Struct UpdateInstanceRequest 

#[non_exhaustive]
pub struct UpdateInstanceRequest { pub update_mask: Option<FieldMask>, pub instance: Option<Instance>, pub request_id: String, pub validate_only: bool, pub allow_missing: bool, /* private fields */ }
Message for updating a Instance

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
update_mask: Option<FieldMask>

Optional. Field mask is used to specify the fields to be overwritten in the Instance resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.

instance: Option<Instance>

Required. The resource being updated

request_id: String

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

validate_only: bool

Optional. If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request.

allow_missing: bool

Optional. If set to true, update succeeds even if instance is not found. In that case, a new instance is created and update_mask is ignored.

Implementations

Source

impl UpdateInstanceRequest

pub fn new() -> Self

pub fn set_update_mask<T>(self, v: T) -> Self
where T: Into<FieldMask>,

Sets the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateInstanceRequest::new().set_update_mask(FieldMask::default()/* use setters */);
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
where T: Into<FieldMask>,

Sets or clears the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateInstanceRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateInstanceRequest::new().set_or_clear_update_mask(None::<FieldMask>);
pub fn set_instance<T>(self, v: T) -> Self
where T: Into<Instance>,

Sets the value of instance.

Example
use google_cloud_alloydb_v1::model::Instance;
let x = UpdateInstanceRequest::new().set_instance(Instance::default()/* use setters */);
pub fn set_or_clear_instance<T>(self, v: Option<T>) -> Self
where T: Into<Instance>,

Sets or clears the value of instance.

Example
use google_cloud_alloydb_v1::model::Instance;
let x = UpdateInstanceRequest::new().set_or_clear_instance(Some(Instance::default()/* use setters */));
let x = UpdateInstanceRequest::new().set_or_clear_instance(None::<Instance>);
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self

Sets the value of request_id.

Example
let x = UpdateInstanceRequest::new().set_request_id("example");
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self

Sets the value of validate_only.

Example
let x = UpdateInstanceRequest::new().set_validate_only(true);
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self

Sets the value of allow_missing.

Example
let x = UpdateInstanceRequest::new().set_allow_missing(true);