UpdateUserRequest

Struct UpdateUserRequest 

#[non_exhaustive]
pub struct UpdateUserRequest { pub update_mask: Option<FieldMask>, pub user: Option<User>, pub request_id: String, pub validate_only: bool, pub allow_missing: bool, /* private fields */ }
Message for updating a User

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
update_mask: Option<FieldMask>

Optional. Field mask is used to specify the fields to be overwritten in the User resource by the update. The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask. If the user does not provide a mask then all fields will be overwritten.

user: Option<User>

Required. The resource being updated

request_id: String

Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server ignores the request if it has already been completed. The server guarantees that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if the original operation with the same request ID was received, and if so, ignores the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

validate_only: bool

Optional. If set, the backend validates the request, but doesn’t actually execute it.

allow_missing: bool

Optional. Allow missing fields in the update mask.

Implementations

Source

impl UpdateUserRequest

pub fn new() -> Self

pub fn set_update_mask<T>(self, v: T) -> Self
where T: Into<FieldMask>,

Sets the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateUserRequest::new().set_update_mask(FieldMask::default()/* use setters */);
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
where T: Into<FieldMask>,

Sets or clears the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateUserRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateUserRequest::new().set_or_clear_update_mask(None::<FieldMask>);
pub fn set_user<T>(self, v: T) -> Self
where T: Into<User>,

Sets the value of user.

Example
use google_cloud_alloydb_v1::model::User;
let x = UpdateUserRequest::new().set_user(User::default()/* use setters */);
pub fn set_or_clear_user<T>(self, v: Option<T>) -> Self
where T: Into<User>,

Sets or clears the value of user.

Example
use google_cloud_alloydb_v1::model::User;
let x = UpdateUserRequest::new().set_or_clear_user(Some(User::default()/* use setters */));
let x = UpdateUserRequest::new().set_or_clear_user(None::<User>);
pub fn set_request_id<T: Into<String>>(self, v: T) -> Self

Sets the value of request_id.

Example
let x = UpdateUserRequest::new().set_request_id("example");
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self

Sets the value of validate_only.

Example
let x = UpdateUserRequest::new().set_validate_only(true);
pub fn set_allow_missing<T: Into<bool>>(self, v: T) -> Self

Sets the value of allow_missing.

Example
let x = UpdateUserRequest::new().set_allow_missing(true);