User

Struct User 

#[non_exhaustive]
pub struct User { pub name: String, pub password: String, pub database_roles: Vec<String>, pub user_type: UserType, pub keep_extra_roles: bool, /* private fields */ }
Message describing User object.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Output only. Name of the resource in the form of projects/{project}/locations/{location}/cluster/{cluster}/users/{user}.

password: String

Input only. Password for the user.

database_roles: Vec<String>

Optional. List of database roles this user has. The database role strings are subject to the PostgreSQL naming conventions.

user_type: UserType

Optional. Type of this user.

keep_extra_roles: bool

Input only. If the user already exists and it has additional roles, keep them granted.

Implementations

Source

impl User

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = User::new().set_name("example");
pub fn set_password<T: Into<String>>(self, v: T) -> Self

Sets the value of password.

Example
let x = User::new().set_password("example");
pub fn set_database_roles<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of database_roles.

Example
let x = User::new().set_database_roles(["a", "b", "c"]);
pub fn set_user_type<T: Into<UserType>>(self, v: T) -> Self

Sets the value of user_type.

Example
use google_cloud_alloydb_v1::model::user::UserType;
let x0 = User::new().set_user_type(UserType::AlloydbBuiltIn);
let x1 = User::new().set_user_type(UserType::AlloydbIamUser);
pub fn set_keep_extra_roles<T: Into<bool>>(self, v: T) -> Self

Sets the value of keep_extra_roles.

Example
let x = User::new().set_keep_extra_roles(true);