PscAutoConnectionConfig

Struct PscAutoConnectionConfig 

#[non_exhaustive]
pub struct PscAutoConnectionConfig { pub consumer_project: String, pub consumer_network: String, pub ip_address: String, pub status: String, pub consumer_network_status: String, /* private fields */ }
Configuration for setting up PSC service automation. Consumer projects in the configs will be allowlisted automatically for the instance.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
consumer_project: String

The consumer project to which the PSC service automation endpoint will be created.

consumer_network: String

The consumer network for the PSC service automation, example: “projects/vpc-host-project/global/networks/default”. The consumer network might be hosted a different project than the consumer project.

ip_address: String

Output only. The IP address of the PSC service automation endpoint.

status: String

Output only. The status of the PSC service automation connection. Possible values: “STATE_UNSPECIFIED” - An invalid state as the default case. “ACTIVE” - The connection has been created successfully. “FAILED” - The connection is not functional since some resources on the connection fail to be created. “CREATING” - The connection is being created. “DELETING” - The connection is being deleted. “CREATE_REPAIRING” - The connection is being repaired to complete creation. “DELETE_REPAIRING” - The connection is being repaired to complete deletion.

consumer_network_status: String

Output only. The status of the service connection policy. Possible values: “STATE_UNSPECIFIED” - Default state, when Connection Map is created initially. “VALID” - Set when policy and map configuration is valid, and their matching can lead to allowing creation of PSC Connections subject to other constraints like connections limit. “CONNECTION_POLICY_MISSING” - No Service Connection Policy found for this network and Service Class “POLICY_LIMIT_REACHED” - Service Connection Policy limit reached for this network and Service Class “CONSUMER_INSTANCE_PROJECT_NOT_ALLOWLISTED” - The consumer instance project is not in AllowedGoogleProducersResourceHierarchyLevels of the matching ServiceConnectionPolicy.

Implementations

Source

impl PscAutoConnectionConfig

pub fn new() -> Self

pub fn set_consumer_project<T: Into<String>>(self, v: T) -> Self

Sets the value of consumer_project.

Example
let x = PscAutoConnectionConfig::new().set_consumer_project("example");
pub fn set_consumer_network<T: Into<String>>(self, v: T) -> Self

Sets the value of consumer_network.

Example
let x = PscAutoConnectionConfig::new().set_consumer_network("example");
pub fn set_ip_address<T: Into<String>>(self, v: T) -> Self

Sets the value of ip_address.

Example
let x = PscAutoConnectionConfig::new().set_ip_address("example");
pub fn set_status<T: Into<String>>(self, v: T) -> Self

Sets the value of status.

Example
let x = PscAutoConnectionConfig::new().set_status("example");
pub fn set_consumer_network_status<T: Into<String>>(self, v: T) -> Self

Sets the value of consumer_network_status.

Example
let x = PscAutoConnectionConfig::new().set_consumer_network_status("example");