#[non_exhaustive]pub struct BatchCreateInstancesMetadata {
pub instance_targets: Vec<String>,
pub instance_statuses: HashMap<String, BatchCreateInstanceStatus>,
/* private fields */
}Expand description
Message for metadata that is specific to BatchCreateInstances API. NEXT_ID: 3
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instance_targets: Vec<String>The instances being created in the API call. Each string in this list is the server defined resource path for target instances in the request and for the format of each string, see the comment on the Instance.name field.
instance_statuses: HashMap<String, BatchCreateInstanceStatus>A map representing state of the instances involved in the BatchCreateInstances operation during the operation execution. The instance state will be in STATE_UNSPECIFIED state if the instance has not yet been picked up for processing. The key of the map is the name of the instance resource. For the format, see the comment on the Instance.name field.
Implementations
Sourceimpl BatchCreateInstancesMetadata
impl BatchCreateInstancesMetadata
pub fn new() -> Self
Sourcepub fn set_instance_targets<T, V>(self, v: T) -> Self
pub fn set_instance_targets<T, V>(self, v: T) -> Self
Sets the value of instance_targets.
Example
ⓘ
let x = BatchCreateInstancesMetadata::new().set_instance_targets(["a", "b", "c"]);Sourcepub fn set_instance_statuses<T, K, V>(self, v: T) -> Self
pub fn set_instance_statuses<T, K, V>(self, v: T) -> Self
Sets the value of instance_statuses.
Example
ⓘ
use google_cloud_alloydb_v1::model::BatchCreateInstanceStatus;
let x = BatchCreateInstancesMetadata::new().set_instance_statuses([
("key0", BatchCreateInstanceStatus::default()/* use setters */),
("key1", BatchCreateInstanceStatus::default()/* use (different) setters */),
]);Trait Implementations
Sourceimpl Clone for BatchCreateInstancesMetadata
impl Clone for BatchCreateInstancesMetadata
Sourcefn clone(&self) -> BatchCreateInstancesMetadata
fn clone(&self) -> BatchCreateInstancesMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatchCreateInstancesMetadata
impl Debug for BatchCreateInstancesMetadata
Sourceimpl Default for BatchCreateInstancesMetadata
impl Default for BatchCreateInstancesMetadata
Sourcefn default() -> BatchCreateInstancesMetadata
fn default() -> BatchCreateInstancesMetadata
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for BatchCreateInstancesMetadata
impl PartialEq for BatchCreateInstancesMetadata
Sourcefn eq(&self, other: &BatchCreateInstancesMetadata) -> bool
fn eq(&self, other: &BatchCreateInstancesMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BatchCreateInstancesMetadata