#[non_exhaustive]pub struct ContinuousBackupSource {
pub cluster: String,
pub point_in_time: Option<Timestamp>,
/* private fields */
}Expand description
Message describing a ContinuousBackupSource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cluster: StringRequired. The source cluster from which to restore. This cluster must have continuous backup enabled for this operation to succeed. For the required format, see the comment on the Cluster.name field.
point_in_time: Option<Timestamp>Required. The point in time to restore to.
Implementations
Sourceimpl ContinuousBackupSource
impl ContinuousBackupSource
pub fn new() -> Self
Sourcepub fn set_cluster<T: Into<String>>(self, v: T) -> Self
pub fn set_cluster<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_point_in_time<T>(self, v: T) -> Self
pub fn set_point_in_time<T>(self, v: T) -> Self
Sets the value of point_in_time.
Example
ⓘ
use wkt::Timestamp;
let x = ContinuousBackupSource::new().set_point_in_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_point_in_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_point_in_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of point_in_time.
Example
ⓘ
use wkt::Timestamp;
let x = ContinuousBackupSource::new().set_or_clear_point_in_time(Some(Timestamp::default()/* use setters */));
let x = ContinuousBackupSource::new().set_or_clear_point_in_time(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for ContinuousBackupSource
impl Clone for ContinuousBackupSource
Sourcefn clone(&self) -> ContinuousBackupSource
fn clone(&self) -> ContinuousBackupSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContinuousBackupSource
impl Debug for ContinuousBackupSource
Sourceimpl Default for ContinuousBackupSource
impl Default for ContinuousBackupSource
Sourcefn default() -> ContinuousBackupSource
fn default() -> ContinuousBackupSource
Returns the “default value” for a type. Read more
Sourceimpl Message for ContinuousBackupSource
impl Message for ContinuousBackupSource
Sourceimpl PartialEq for ContinuousBackupSource
impl PartialEq for ContinuousBackupSource
impl StructuralPartialEq for ContinuousBackupSource